@@ -77,7 +77,7 @@ def _construct_session(
     return session_obj
 
 
-def _mv_legacy_headers_for_service(mv_service_type: str) -> ty.List[str]:
+def _mv_legacy_headers_for_service(mv_service_type: str) -> list[str]:
     """Workaround for services that predate standardization.
 
     TODO(sdague): eventually convert this to using os-service-types
@@ -95,8 +95,8 @@ def _mv_legacy_headers_for_service(mv_service_type: str) -> ty.List[str]:
 
 
 def _sanitize_headers(
-    headers: ty.Dict[ty.Union[str, bytes], ty.Any],
-) -> ty.Dict[str, ty.Any]:
+    headers: dict[ty.Union[str, bytes], ty.Any],
+) -> dict[str, ty.Any]:
     """Ensure headers are strings and not bytes."""
     str_dict = {}
     for k, v in headers.items():
@@ -370,7 +370,7 @@ class Session:
         session: ty.Optional[requests.Session] = None,
         original_ip: ty.Optional[str] = None,
         verify: ty.Union[bool, str, None] = True,
-        cert: ty.Union[str, ty.Tuple[str, str], None] = None,
+        cert: ty.Union[str, tuple[str, str], None] = None,
         timeout: ty.Optional[int] = None,
         user_agent: ty.Optional[str] = None,
         redirect: ty.Union[int, bool] = _DEFAULT_REDIRECT_LIMIT,
@@ -379,8 +379,8 @@ class Session:
         ] = None,
         app_name: ty.Optional[str] = None,
         app_version: ty.Optional[str] = None,
-        additional_user_agent: ty.Optional[ty.List[ty.Tuple[str, str]]] = None,
-        discovery_cache: ty.Optional[ty.Dict[str, ty.Any]] = None,
+        additional_user_agent: ty.Optional[list[tuple[str, str]]] = None,
+        discovery_cache: ty.Optional[dict[str, ty.Any]] = None,
         split_loggers: ty.Optional[bool] = None,
         collect_timing: bool = False,
         rate_semaphore: ty.Optional[ty.ContextManager[None]] = None,
@@ -413,7 +413,7 @@ class Session:
         self._split_loggers = split_loggers
         self._collect_timing = collect_timing
         self._connect_retries = connect_retries
-        self._api_times: ty.List[RequestTiming] = []
+        self._api_times: list[RequestTiming] = []
         self._rate_semaphore = rate_semaphore or NoOpSemaphore()
 
         if timeout is not None:
@@ -475,7 +475,7 @@ class Session:
         return body
 
     @staticmethod
-    def _process_header(header: ty.Tuple[str, str]) -> ty.Tuple[str, str]:
+    def _process_header(header: tuple[str, str]) -> tuple[str, str]:
         """Redact the secure headers to be logged."""
         secure_headers = (
             'authorization',
@@ -517,7 +517,7 @@ class Session:
         data: ty.Union[str, bytes, None] = None,
         json: object = None,
         headers: ty.Optional[collections.abc.MutableMapping[str, str]] = None,
-        query_params: ty.Optional[ty.Dict[str, ty.Any]] = None,
+        query_params: ty.Optional[dict[str, ty.Any]] = None,
         logger: ty.Optional[logging.Logger] = None,
         split_loggers: ty.Optional[bool] = None,
     ) -> None:
@@ -660,7 +660,7 @@ class Session:
         headers: collections.abc.MutableMapping[str, str],
         microversion: str,
         service_type: ty.Optional[str],
-        endpoint_filter: ty.Optional[ty.Dict[str, ty.Any]],
+        endpoint_filter: ty.Optional[dict[str, ty.Any]],
     ) -> None:
         # We're converting it to normalized version number for two reasons.
         # First, to validate it's a real version number. Second, so that in
@@ -726,7 +726,7 @@ class Session:
         user_agent: ty.Optional[str] = None,
         redirect: ty.Union[int, bool, None] = None,
         authenticated: ty.Optional[bool] = None,
-        endpoint_filter: ty.Optional[ty.Dict[str, ty.Any]] = None,
+        endpoint_filter: ty.Optional[dict[str, ty.Any]] = None,
         auth: ty.Optional['plugin.BaseAuthPlugin'] = None,
         requests_auth: ty.Optional['requests.auth.AuthBase'] = None,
         raise_exc: bool = True,
@@ -735,13 +735,13 @@ class Session:
         endpoint_override: ty.Optional[str] = None,
         connect_retries: ty.Optional[int] = None,
         logger: ty.Optional[logging.Logger] = None,
-        allow: ty.Optional[ty.Dict[str, ty.Any]] = None,
+        allow: ty.Optional[dict[str, ty.Any]] = None,
         client_name: ty.Optional[str] = None,
         client_version: ty.Optional[str] = None,
         microversion: ty.Optional[str] = None,
         microversion_service_type: ty.Optional[str] = None,
         status_code_retries: int = 0,
-        retriable_status_codes: ty.Optional[ty.List[int]] = None,
+        retriable_status_codes: ty.Optional[list[int]] = None,
         rate_semaphore: ty.Optional[ty.ContextManager[None]] = None,
         global_request_id: ty.Optional[str] = None,
         connect_retry_delay: ty.Optional[float] = None,
@@ -1146,7 +1146,7 @@ class Session:
         split_loggers: ty.Optional[bool],
         connect_retries: int,
         status_code_retries: int,
-        retriable_status_codes: ty.List[int],
+        retriable_status_codes: list[int],
         rate_semaphore: ty.ContextManager[None],
         connect_retry_delays: _Retries,
         status_code_retry_delays: _Retries,
@@ -1367,10 +1367,8 @@ class Session:
         return auth
 
     def get_auth_headers(
-        self,
-        auth: ty.Optional['plugin.BaseAuthPlugin'] = None,
-        **kwargs: ty.Any,
-    ) -> ty.Optional[ty.Dict[str, str]]:
+        self, auth: ty.Optional['plugin.BaseAuthPlugin'] = None
+    ) -> ty.Optional[dict[str, str]]:
         """Return auth headers as provided by the auth plugin.
 
         :param auth: The auth plugin to use for token. Overrides the plugin
@@ -1386,7 +1384,7 @@ class Session:
         :rtype: :class:`dict`
         """
         auth = self._auth_required(auth, 'fetch a token')
-        return auth.get_headers(self, **kwargs)
+        return auth.get_headers(self)
 
     def get_token(
         self, auth: ty.Optional['plugin.BaseAuthPlugin'] = None
@@ -1463,7 +1461,7 @@ class Session:
         self,
         auth: ty.Optional['plugin.BaseAuthPlugin'] = None,
         **kwargs: ty.Any,
-    ) -> ty.Optional[ty.Tuple[ty.Union[int, float], ...]]:
+    ) -> ty.Optional[tuple[ty.Union[int, float], ...]]:
         """Get the major API version as provided by the auth plugin.
 
         :param auth: The auth plugin to use for token. Overrides the plugin on
@@ -1482,13 +1480,10 @@ class Session:
     def get_all_version_data(
         self,
         auth: ty.Optional['plugin.BaseAuthPlugin'] = None,
-        interface: str = 'public',
+        interface: ty.Union[str, list[str], None] = 'public',
         region_name: ty.Optional[str] = None,
         service_type: ty.Optional[str] = None,
-        **kwargs: ty.Any,
-    ) -> ty.Dict[
-        str, ty.Dict[str, ty.Dict[str, ty.List[discover.VersionData]]]
-    ]:
+    ) -> dict[str, dict[str, dict[str, list[discover.VersionData]]]]:
         """Get version data for all services in the catalog.
 
         :param auth:
@@ -1516,14 +1511,11 @@ class Session:
             interface=interface,
             region_name=region_name,
             service_type=service_type,
-            **kwargs,
         )
 
     def get_auth_connection_params(
-        self,
-        auth: ty.Optional['plugin.BaseAuthPlugin'] = None,
-        **kwargs: ty.Any,
-    ) -> ty.Dict[str, ty.Any]:
+        self, auth: ty.Optional['plugin.BaseAuthPlugin'] = None
+    ) -> 'plugin.ConnectionParams':
         """Return auth connection params as provided by the auth plugin.
 
         An auth plugin may specify connection parameters to the request like
@@ -1531,7 +1523,7 @@ class Session:
 
         We restrict the values that may be returned from this function to
         prevent an auth plugin overriding values unrelated to connection
-        parmeters. The values that are currently accepted are:
+        parameters. The values that are currently accepted are:
 
         - `cert`: a path to a client certificate, or tuple of client
           certificate and key pair that are used with this request.
@@ -1557,22 +1549,19 @@ class Session:
         :rtype: :class:`dict`
         """
         auth = self._auth_required(auth, 'fetch connection params')
-        params = auth.get_connection_params(self, **kwargs)
+        params = auth.get_connection_params(self)
 
         # NOTE(jamielennox): There needs to be some consensus on what
         # parameters are allowed to be modified by the auth plugin here.
         # Ideally I think it would be only the send() parts of the request
         # flow. For now lets just allow certain elements.
-        params_copy = params.copy()
-
-        for arg in ('cert', 'verify'):
-            try:
-                kwargs[arg] = params_copy.pop(arg)
-            except KeyError:
-                pass
-
-        if params_copy:
-            raise exceptions.UnsupportedParameters(list(params_copy.keys()))
+        # NOTE(stephenfin): We can't rely on type checking to validate the
+        # return values of plugins since these don't happen at runtime. It
+        # would be much nicer if we insisted the plugins returned a two-item
+        # tuple instead.
+        invalid_keys = set(params) - {'cert', 'verify'}
+        if invalid_keys:
+            raise exceptions.UnsupportedParameters(list(invalid_keys))
 
         return params
 
@@ -1628,7 +1617,7 @@ class Session:
         auth = self._auth_required(auth, 'get project_id')
         return auth.get_project_id(self)
 
-    def get_timings(self) -> ty.List[RequestTiming]:
+    def get_timings(self) -> list[RequestTiming]:
         """Return collected API timing information.
 
         :returns: List of `RequestTiming` objects.
